import Foundation

public extension String {

    var quoted: String {
        "\"\(self)\""
    }
}
